==> kubernetes-model-1.0.13-sources.jar: io/fabric8/openshift/api/model/BuildRequestFluent.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectReference;
import java.util.HashMap;
import java.util.Map;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.model.ObjectReferenceFluent;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import io.fabric8.kubernetes.api.model.ObjectReferenceBuilder;

public class BuildRequestFluent<T extends BuildRequestFluent<T>> extends BaseFluent<T> implements Fluent<T>{

     BuildRequest.ApiVersion apiVersion;     String kind;     VisitableBuilder<ObjectMeta, ?> metadata;     VisitableBuilder<SourceRevision, ?> revision;     VisitableBuilder<ObjectReference, ?> triggeredByImage;     Map<String, Object> additionalProperties = new HashMap();

    public BuildRequest.ApiVersion getApiVersion(){
    return this.apiVersion;
    }
    public T withApiVersion( BuildRequest.ApiVersion apiVersion){
    this.apiVersion=apiVersion; return (T) this;
    }
    public String getKind(){
    return this.kind;
    }
    public T withKind( String kind){
    this.kind=kind; return (T) this;
    }
    public ObjectMeta getMetadata(){
    return this.metadata!=null?this.metadata.build():null;
    }
    public T withMetadata( ObjectMeta metadata){
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.add(this.metadata);} return (T) this;
    }
    public MetadataNested<T> withNewMetadata(){
    return new MetadataNested<T>();
    }
    public MetadataNested<T> withNewMetadataLike( ObjectMeta item){
    return new MetadataNested<T>(item);
    }
    public MetadataNested<T> editMetadata(){
    return withNewMetadataLike(getMetadata());
    }
    public SourceRevision getRevision(){
    return this.revision!=null?this.revision.build():null;
    }
    public T withRevision( SourceRevision revision){
    if (revision!=null){ this.revision= new SourceRevisionBuilder(revision); _visitables.add(this.revision);} return (T) this;
    }
    public RevisionNested<T> withNewRevision(){
    return new RevisionNested<T>();
    }
    public RevisionNested<T> withNewRevisionLike( SourceRevision item){
    return new RevisionNested<T>(item);
    }
    public RevisionNested<T> editRevision(){
    return withNewRevisionLike(getRevision());
    }
    public ObjectReference getTriggeredByImage(){
    return this.triggeredByImage!=null?this.triggeredByImage.build():null;
    }
    public T withTriggeredByImage( ObjectReference triggeredByImage){
    if (triggeredByImage!=null){ this.triggeredByImage= new ObjectReferenceBuilder(triggeredByImage); _visitables.add(this.triggeredByImage);} return (T) this;
    }
    public TriggeredByImageNested<T> withNewTriggeredByImage(){
    return new TriggeredByImageNested<T>();
    }
    public TriggeredByImageNested<T> withNewTriggeredByImageLike( ObjectReference item){
    return new TriggeredByImageNested<T>(item);
    }
    public TriggeredByImageNested<T> editTriggeredByImage(){
    return withNewTriggeredByImageLike(getTriggeredByImage());
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public T removeFromAdditionalProperties( String key){
    if(key != null) {this.additionalProperties.remove(key);} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }
    public boolean equals( Object o){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
BuildRequestFluent that = (BuildRequestFluent) o;
if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
if (revision != null ? !revision.equals(that.revision) :that.revision != null) return false;
if (triggeredByImage != null ? !triggeredByImage.equals(that.triggeredByImage) :that.triggeredByImage != null) return false;
if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
return true;

    }

    public class MetadataNested<N> extends ObjectMetaFluent<MetadataNested<N>> implements Nested<N>{

        private final ObjectMetaBuilder builder;
    
             MetadataNested (){
        this.builder = new ObjectMetaBuilder(this);
        }
             MetadataNested ( ObjectMeta item){
        this.builder = new ObjectMetaBuilder(this, item);
        }
    
            public N endMetadata(){
            return and();
        }
            public N and(){
            return (N) BuildRequestFluent.this.withMetadata(builder.build());
        }
    
}
    public class RevisionNested<N> extends SourceRevisionFluent<RevisionNested<N>> implements Nested<N>{

        private final SourceRevisionBuilder builder;
    
             RevisionNested (){
        this.builder = new SourceRevisionBuilder(this);
        }
             RevisionNested ( SourceRevision item){
        this.builder = new SourceRevisionBuilder(this, item);
        }
    
            public N endRevision(){
            return and();
        }
            public N and(){
            return (N) BuildRequestFluent.this.withRevision(builder.build());
        }
    
}
    public class TriggeredByImageNested<N> extends ObjectReferenceFluent<TriggeredByImageNested<N>> implements Nested<N>{

        private final ObjectReferenceBuilder builder;
    
             TriggeredByImageNested (){
        this.builder = new ObjectReferenceBuilder(this);
        }
             TriggeredByImageNested ( ObjectReference item){
        this.builder = new ObjectReferenceBuilder(this, item);
        }
    
            public N endTriggeredByImage(){
            return and();
        }
            public N and(){
            return (N) BuildRequestFluent.this.withTriggeredByImage(builder.build());
        }
    
}


}

==> kubernetes-model-1.0.19-sources.jar: io/fabric8/openshift/api/model/BuildRequestFluent.java <==
package io.fabric8.openshift.api.model;

import java.util.Map;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import java.util.HashMap;
import io.fabric8.kubernetes.api.model.ObjectReference;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import io.fabric8.kubernetes.api.model.ObjectReferenceFluent;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.model.ObjectReferenceBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;

public class BuildRequestFluent<T extends BuildRequestFluent<T>> extends BaseFluent<T> implements Fluent<T>{

     BuildRequest.ApiVersion apiVersion;     VisitableBuilder<ObjectReference, ?> from;     String kind;     Integer lastVersion;     VisitableBuilder<ObjectMeta, ?> metadata;     VisitableBuilder<SourceRevision, ?> revision;     VisitableBuilder<ObjectReference, ?> triggeredByImage;     Map<String, Object> additionalProperties = new HashMap();

    public BuildRequest.ApiVersion getApiVersion(){
    return this.apiVersion;
    }
    public T withApiVersion( BuildRequest.ApiVersion apiVersion){
    this.apiVersion=apiVersion; return (T) this;
    }
    public ObjectReference getFrom(){
    return this.from!=null?this.from.build():null;
    }
    public T withFrom( ObjectReference from){
    if (from!=null){ this.from= new ObjectReferenceBuilder(from); _visitables.add(this.from);} return (T) this;
    }
    public FromNested<T> withNewFrom(){
    return new FromNested<T>();
    }
    public FromNested<T> withNewFromLike( ObjectReference item){
    return new FromNested<T>(item);
    }
    public FromNested<T> editFrom(){
    return withNewFromLike(getFrom());
    }
    public String getKind(){
    return this.kind;
    }
    public T withKind( String kind){
    this.kind=kind; return (T) this;
    }
    public Integer getLastVersion(){
    return this.lastVersion;
    }
    public T withLastVersion( Integer lastVersion){
    this.lastVersion=lastVersion; return (T) this;
    }
    public ObjectMeta getMetadata(){
    return this.metadata!=null?this.metadata.build():null;
    }
    public T withMetadata( ObjectMeta metadata){
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.add(this.metadata);} return (T) this;
    }
    public MetadataNested<T> withNewMetadata(){
    return new MetadataNested<T>();
    }
    public MetadataNested<T> withNewMetadataLike( ObjectMeta item){
    return new MetadataNested<T>(item);
    }
    public MetadataNested<T> editMetadata(){
    return withNewMetadataLike(getMetadata());
    }
    public SourceRevision getRevision(){
    return this.revision!=null?this.revision.build():null;
    }
    public T withRevision( SourceRevision revision){
    if (revision!=null){ this.revision= new SourceRevisionBuilder(revision); _visitables.add(this.revision);} return (T) this;
    }
    public RevisionNested<T> withNewRevision(){
    return new RevisionNested<T>();
    }
    public RevisionNested<T> withNewRevisionLike( SourceRevision item){
    return new RevisionNested<T>(item);
    }
    public RevisionNested<T> editRevision(){
    return withNewRevisionLike(getRevision());
    }
    public ObjectReference getTriggeredByImage(){
    return this.triggeredByImage!=null?this.triggeredByImage.build():null;
    }
    public T withTriggeredByImage( ObjectReference triggeredByImage){
    if (triggeredByImage!=null){ this.triggeredByImage= new ObjectReferenceBuilder(triggeredByImage); _visitables.add(this.triggeredByImage);} return (T) this;
    }
    public TriggeredByImageNested<T> withNewTriggeredByImage(){
    return new TriggeredByImageNested<T>();
    }
    public TriggeredByImageNested<T> withNewTriggeredByImageLike( ObjectReference item){
    return new TriggeredByImageNested<T>(item);
    }
    public TriggeredByImageNested<T> editTriggeredByImage(){
    return withNewTriggeredByImageLike(getTriggeredByImage());
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public T removeFromAdditionalProperties( String key){
    if(key != null) {this.additionalProperties.remove(key);} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }
    public boolean equals( Object o){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
BuildRequestFluent that = (BuildRequestFluent) o;
if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
if (from != null ? !from.equals(that.from) :that.from != null) return false;
if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
if (lastVersion != null ? !lastVersion.equals(that.lastVersion) :that.lastVersion != null) return false;
if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
if (revision != null ? !revision.equals(that.revision) :that.revision != null) return false;
if (triggeredByImage != null ? !triggeredByImage.equals(that.triggeredByImage) :that.triggeredByImage != null) return false;
if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
return true;

    }

    public class FromNested<N> extends ObjectReferenceFluent<FromNested<N>> implements Nested<N>{

        private final ObjectReferenceBuilder builder;
    
             FromNested (){
        this.builder = new ObjectReferenceBuilder(this);
        }
             FromNested ( ObjectReference item){
        this.builder = new ObjectReferenceBuilder(this, item);
        }
    
            public N endFrom(){
            return and();
        }
            public N and(){
            return (N) BuildRequestFluent.this.withFrom(builder.build());
        }
    
}
    public class MetadataNested<N> extends ObjectMetaFluent<MetadataNested<N>> implements Nested<N>{

        private final ObjectMetaBuilder builder;
    
             MetadataNested (){
        this.builder = new ObjectMetaBuilder(this);
        }
             MetadataNested ( ObjectMeta item){
        this.builder = new ObjectMetaBuilder(this, item);
        }
    
            public N and(){
            return (N) BuildRequestFluent.this.withMetadata(builder.build());
        }
            public N endMetadata(){
            return and();
        }
    
}
    public class RevisionNested<N> extends SourceRevisionFluent<RevisionNested<N>> implements Nested<N>{

        private final SourceRevisionBuilder builder;
    
             RevisionNested (){
        this.builder = new SourceRevisionBuilder(this);
        }
             RevisionNested ( SourceRevision item){
        this.builder = new SourceRevisionBuilder(this, item);
        }
    
            public N endRevision(){
            return and();
        }
            public N and(){
            return (N) BuildRequestFluent.this.withRevision(builder.build());
        }
    
}
    public class TriggeredByImageNested<N> extends ObjectReferenceFluent<TriggeredByImageNested<N>> implements Nested<N>{

        private final ObjectReferenceBuilder builder;
    
             TriggeredByImageNested ( ObjectReference item){
        this.builder = new ObjectReferenceBuilder(this, item);
        }
             TriggeredByImageNested (){
        this.builder = new ObjectReferenceBuilder(this);
        }
    
            public N and(){
            return (N) BuildRequestFluent.this.withTriggeredByImage(builder.build());
        }
            public N endTriggeredByImage(){
            return and();
        }
    
}


}
